<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fi">
<context>
    <name>QmmpFileDialog</name>
    <message>
        <location filename="../qmmpfiledialog.ui" line="13"/>
        <source>Add Files</source>
        <translation>Dateien hinzufügen</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="37"/>
        <source>Up</source>
        <translation>Nach oben</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="40"/>
        <location filename="../qmmpfiledialog.ui" line="53"/>
        <location filename="../qmmpfiledialog.ui" line="72"/>
        <location filename="../qmmpfiledialog.ui" line="97"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="50"/>
        <source>List view</source>
        <translation>Listenansicht</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="69"/>
        <source>Detailed view</source>
        <translation>Detailansicht</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="94"/>
        <source>Close dialog on add</source>
        <translation>Dialog nach Hinzufügen schließen</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="177"/>
        <source>File name:</source>
        <translation>Dateiname:</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="193"/>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="200"/>
        <source>Files of type:</source>
        <translation>Filter:</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="226"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
</context>
<context>
    <name>QmmpFileDialogFactory</name>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="121"/>
        <location filename="../qmmpfiledialog.cpp" line="130"/>
        <source>Qmmp File Dialog</source>
        <translation>Qmmp Datei-Dialog</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="129"/>
        <source>About Qmmp File Dialog</source>
        <translation>Über Qmmp Datei-Dialog</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="131"/>
        <source>Writen by:
Vladimir Kuznetsov &lt;vovanec@gmail.com&gt;
Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autoren:
Vladimir Kuznetsov &lt;vovanec@gmail.com&gt;
Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="134"/>
        <source>Some code is copied from the Qt library</source>
        <translation>Einige Codezeilen wurden von der Qt-Bibliothek übernommen</translation>
    </message>
</context>
<context>
    <name>QmmpFileDialogImpl</name>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="259"/>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="272"/>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="288"/>
        <source>Directories</source>
        <translation>Verzeichnisse</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="457"/>
        <source>already exists.</source>
        <translation>existiert bereits.</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="458"/>
        <source>Do you want to replace it?</source>
        <translation>Möchten Sie es ersetzen?</translation>
    </message>
</context>
</TS>
